package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````U!\```````!``````````*BQ````
M`````````$``.``)`$``&@`9``8````$````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````;`````````!L``````````0`````````!````
M!0```````````````````````````````````,"=````````P)T`````````
M``$```````$````&````,*L````````PJP$``````#"K`0``````4`4`````
M``!X%0```````````0```````@````8```!`JP```````$"K`0``````0*L!
M```````P`@```````#`"````````"``````````$````!````%0"````````
M5`(```````!4`@```````$0`````````1``````````$`````````%#E=&0$
M````/)8````````\E@```````#R6````````#`$````````,`0````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````#"K````````,*L!```````PJP$`
M`````-`$````````T`0````````!`````````"]L:6(O;&0M;&EN=7@M86%R
M8V@V-"YS;RXQ```$````%`````,```!'3E4`%L\D[,:"`VH"`S:WTS\*BD>O
M?'<$````$`````$```!'3E4```````,````'`````````#T```!+````!```
M``@````A$!``!<`$A"@"$`6`AD"$@@D`!`D@!(B(H!!%N@`""```````````
M2P````````!,````30```$\`````````4`````````!1````4@```%,```!4
M`````````%4```!7`````````````````````````````````````````%@`
M``!9````6P```%T```````````````````!>`````````%\`````````8```
M`&$`````````8@```&,`````````9````&4`````````````````````````
M`````&8``````````````&<`````````:```````````````:0``````````
M``````````````"[XY)\:QJ>4"[%F[9#^M>'%8PES&>OS&9OQ=\?B0=PTZ/@
M^TG[H6Q@`*\TZ+_:5QO59-1\P^4_+'ZIG)NM2^/`XD?&`<_>1RT-%.*>(?_D
M#N&G`@K;S>.>6>^7>7=4/)2S`8MO#3J7"]EQ6!PS8MOM:PE#UD-%U>QK?YI\
M``````````````````````````````````````,`"P#('```````````````
M``````````,`%@``L`$`````````````````1`(``!(`````````````````
M````````NP(``!(`````````````````````````%`(``!(`````````````
M````````````&P(``!(`````````````````````````K0(``!(`````````
M````````````````O0$``!(``````````````````````````0```"``````
M````````````````````;`(``!(`````````````````````````A`(``!(`
M````````````````````````G@(``"(`````````````````````````?0(`
M`!(`````````````````````````9`(``!(`````````````````````````
M=@(``!$`````````````````````````EP```!(`````````````````````
M````[0(``!(`````````````````````````V````!(`````````````````
M````````%0$``!(`````````````````````````!@(``!(`````````````
M````````````*P$``!(`````````````````````````<P$``!$`````````
M````````````````2P(``!(`````````````````````````YP```!(`````
M````````````````````1@```!$`````````````````````````NP```!(`
M````````````````````````P@$``!(`````````````````````````T0(`
M`!(`````````````````````````(@(``!(`````````````````````````
M]0```!(`````````````````````````FP$``!(`````````````````````
M````'P$``!(`````````````````````````HP$``!(`````````````````
M````````\0$``!(`````````````````````````#0(``!(`````````````
M````````````R@$``!(`````````````````````````TP$``!(`````````
M````````````````MP$``!(`````````````````````````4P```!(`````
M````````````````````'0```"``````````````````````````_P(``!$`
M````````````````````````Y`(``"$`````````````````````````^0$`
M`!(`````````````````````````PP(``!(`````````````````````````
M,@$``!(`````````````````````````-@(``!(`````````````````````
M````R@(``!(`````````````````````````C0,``!(`````````````````
M````````,`(``!(`````````````````````````@````!(`````````````
M``````````````$``!(`````````````````````````C````!(`````````
M````````````````60(``!(`````````````````````````4@$``!(`````
M````````````````````&@$``!(`````````````````````````90$``!(`
M````````````````````````E`(``!(`````````````````````````8P``
M`!(`````````````````````````L````!(`````````````````````````
M00$``!(`````````````````````````C0(``!(`````````````````````
M````;P```!(`````````````````````````CP$``!(`````````````````
M````````_P$``!(`````````````````````````XP(``!$`````````````
M````````````Y0(``!$`````````````````````````E`$``!(`````````
M````````````````R0```!(`````````````````````````IP```!(`````
M````````````````````*0(``!(`````````````````````````+````"``
M````````````````````````?@$``!(`````````````````````````Y`$`
M`!(`````````````````````````ZP$``!(`````````````````````````
M,@0``!``%P"HP`$`````````````````3`0``!(`#0!@5````````*P!````
M````7`,``!(`#0!@*P````````0`````````VP,``!(`#0`P4P```````"@!
M````````EP0``!(`#0#04@```````%P`````````P@,``!(`#0`0+@``````
M`"0`````````E@,``!(`#0#@0````````&`!````````*`0``!$`%@!XL`$`
M``````@`````````/P0``!(`#0`T+@```````"@%````````=P0``!(`#0`@
M-````````$`!````````J@,``!``%P"HP`$`````````````````J0,``!``
M%P"HP`$`````````````````H`0``!(`#0#P/0```````.P"````````8@0`
M`!(`#0``*@```````$@`````````>P,``!(`#0#P,P```````#``````````
M\P,``!$`#P#`5@````````0`````````M0,``!(`#0#D+0```````"0`````
M````S@,``!(`#0!@-0```````)`(````````3`,``!(`#0"05@````````0`
M````````:@0``!(`#0!D*P```````(`"`````````@0``!(`#0!0*@``````
M``@!````````&`0``!(`#0`05@```````'P`````````-P0``!``%P"HP`$`
M````````````````;0,``!``%P"`L`$`````````````````B00``!(`#0!@
M,P```````)``````````Z`,``"``%@``L`$`````````````````5@0``!``
M%P"`L`$`````````````````[`,``!(`#0#4'P``````````````````Y@,`
M`!``%@``L`$`````````````````H@,``!``%@"`L`$`````````````````
MW@(``!(`#0!`'0```````)0"`````````%])5$U?9&5R96=I<W1E<E1-0VQO
M;F5486)L90!?7V=M;VY?<W1A<G1?7P!?251-7W)E9VES=&5R5$U#;&]N951A
M8FQE`%!,7V1O7W5N9'5M<`!097)L7V=V7V9E=&-H<'8`4&5R;%]M9U]S970`
M4&5R;%]A=&9O<FM?;&]C:P!097)L7V=E=%]S=@!097)L7VYE=UA3`&)O;W1?
M1'EN84QO861E<@!P97)L7W)U;@!P97)L7W!A<G-E`%!E<FQ?<W9?<V5T<'8`
M4&5R;%]S=E]S971P=FX`<&5R;%]C;VYS=')U8W0`<&5R;%]D97-T<G5C=`!P
M97)L7V%L;&]C`%!E<FQ?8W)O86M?;F]C;VYT97AT`'!E<FQ?9G)E90!097)L
M7W-A9F5S>7-M86QL;V,`4&5R;%]S>7-?:6YI=#,`4&5R;%]N97=84U]F;&%G
M<P!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S>7-?=&5R;0!03%]T:')?:V5Y
M`%]?97)R;F]?;&]C871I;VX`<F5A9`!O<&5N-C0`;'-E96LV-`!P=&AR96%D
M7V=E='-P96-I9FEC`&-L;W-E`&5X:70`<W1R;F-M<`!C;&]S961I<@!?7W-T
M86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&%B;W)T`&UE;6-H
M<@!G971P:60`<W1R9'5P`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T<@!R
M;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?;'AS
M=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R`&=E='5I9`!R96%D;&EN
M:P!S=')C:'(`<F5A9&1I<C8T`%]?8WAA7V9I;F%L:7IE`%]?<W!R:6YT9E]C
M:&L`;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?
M96YV:7)O;@!?7W)E9VES=&5R7V%T9F]R:P!?7W-T86-K7V-H:U]G=6%R9`!L
M:6)P97)L+G-O`&QI8G!T:')E860N<V\N,`!L:6)C+G-O+C8`;&0M;&EN=7@M
M86%R8V@V-"YS;RXQ`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R<F5N=%]E>&5C
M`%]?8G-S7W-T87)T7U\`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R
M7V-L96%N=7``7V5D871A`%]?8G-S7V5N9%]?`'!A<E]B87-E;F%M90!P87)?
M9&ER;F%M90!P87)?;6MT;7!D:7(`<VAA7W5P9&%T90!?7V1A=&%?<W1A<G0`
M7TE/7W-T9&EN7W5S960`<&%R7V-U<G)E;G1?97AE8U]P<F]C`%]?;&EB8U]C
M<W5?:6YI=`!M>5]P87)?<&P`7V5N9`!?7V5N9%]?`'!A<E]I;FET7V5N=@!S
M:&%?9FEN86P`7U]B<W-?<W1A<G0`>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R
M7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!S:&%?:6YI=`!84U]);G1E
M<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXQ-P`O=7-R+VQI8B]P97)L-2\U+C,T
M+V-O<F5?<&5R;"]#3U)%``````````(``@`"``(``@`"`````@`"``(``@`"
M``(````"```````"``(````"``````````(``@`"`````P````,``@`"``(`
M`@`#```````$``(``@`"`````@`"``(``@`````````"`````@````(`````
M`````@````,``@`"``(``P```````@````,``@`"``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!`#8#```0````(````)>1E@8```0`M@0````````!``$`'`,``!``
M```@````EY&6!@```P"V!`````````$``0`L`P``$`````````"7D98&```"
M`+8$````````,*L!```````#!````````/`@````````.*L!```````#!```
M`````*`@````````N*T!```````#!````````)!6````````F*X!```````#
M!````````#!3````````$*\!```````#!````````!!6````````2*\!````
M```#!````````*!6````````@*\!```````#!````````&!4````````D*\!
M```````#!````````$`=````````X*\!```````#!````````-!2````````
M"+`!```````#!`````````BP`0``````&+`!```````#!````````,A6````
M````(+`!```````#!````````-!6````````,+`!```````#!````````-A6
M````````.+`!```````#!````````.A6````````0+`!```````#!```````
M`/!6````````2+`!```````#!````````/A6````````4+`!```````#!```
M``````!7````````8+`!```````#!`````````A7````````:+`!```````#
M!````````!!7````````>+`!```````#!````````(A:````````L*T!````
M```!!````P``````````````P*T!```````!!```!```````````````R*T!
M```````!!```!0``````````````T*T!```````!!```!@``````````````
MV*T!```````!!```!P``````````````X*T!```````!!```"```````````
M````Z*T!```````!!```"0``````````````\*T!```````!!```"@``````
M````````^*T!```````!!```"P```````````````*X!```````!!```#```
M````````````"*X!```````!!```#0``````````````$*X!```````!!```
M#@``````````````&*X!```````!!```#P``````````````(*X!```````!
M!```$```````````````**X!```````!!```$@``````````````,*X!````
M```!!```$P``````````````.*X!```````!!```%```````````````0*X!
M```````!!```%0``````````````2*X!```````!!```%@``````````````
M4*X!```````!!```%P``````````````6*X!```````!!```&```````````
M````8*X!```````!!```&0``````````````:*X!```````!!```&@``````
M````````<*X!```````!!```&P``````````````>*X!```````!!```'0``
M````````````@*X!```````!!```'@``````````````B*X!```````!!```
M'P``````````````D*X!```````!!```(```````````````H*X!```````!
M!```(0``````````````J*X!```````!!```(@``````````````L*X!````
M```!!```(P``````````````N*X!```````!!```)```````````````P*X!
M```````!!```)0``````````````R*X!```````!!```)@``````````````
MT*X!```````!!```)P``````````````V*X!```````!!```*```````````
M````X*X!```````!!```*0``````````````Z*X!```````!!```+```````
M````````\*X!```````!!```+0``````````````^*X!```````!!```+@``
M`````````````*\!```````!!```+P``````````````"*\!```````!!```
M,```````````````&*\!```````!!```,0``````````````(*\!```````!
M!```,@``````````````**\!```````!!```,P``````````````,*\!````
M```!!```-```````````````.*\!```````!!```-0``````````````0*\!
M```````!!```-@``````````````4*\!```````!!```-P``````````````
M6*\!```````!!```.```````````````8*\!```````!!```.0``````````
M````:*\!```````!!```.@``````````````<*\!```````!!```.P``````
M````````>*\!```````!!```/```````````````B*\!```````!!```/0``
M````````````F*\!```````!!```/@``````````````H*\!```````!!```
M/P``````````````J*\!```````!!```0```````````````L*\!```````!
M!```0@``````````````N*\!```````!!```0P``````````````P*\!````
M```!!```1```````````````R*\!```````!!```10``````````````T*\!
M```````!!```1@``````````````V*\!```````!!```1P``````````````
MZ*\!```````!!```2```````````````\*\!```````!!```20``````````
M````^*\!```````!!```2@``````````````B*T!```````"!```$0``````
M````````D*T!```````"!```'```````````````F*T!```````"!```*```
M````````````H*T!```````"!```*P``````````````7R0#U?U[OZG]`P"1
MSP``E/U[P:C``U_6\'N_J=```+`1PD;Y$`(VD2`"']8?(`/5'R`#U1\@`]70
M``"P$<9&^1`B-I$@`A_6T```L!'*1OD00C:1(`(?UM```+`1SD;Y$&(VD2`"
M'];0``"P$=)&^1""-I$@`A_6_7NYJ?T#`)'S4P&IU```L(-R1_GU6P*I]QL`
M^>*'!*GB(P&19`!`^>0W`/D$`(#2PP``L.%#`9'@7P"YX',!D6-X1_E@`#_6
MP```L,(``+##``"P0J!'^0#,1_GA`P*J8Z1'^6``/];```"P`#!'^0``0#E@
M"P`TTP``T-4``+#6``"PM29'^=921_F@`D"YP`(_U@(H4CE"`!\R`B@2.:`"
M0+G``C_6`RA2.<$``+#B7T"Y8P``,@,H$CDA2$?Y0!``$54,`!$`?'V3(``_
MUN,#`*KF*T#YP```T&0B`I'E7T"Y`CQ`^2$``)#'`$#Y(>`ID2```)```"J1
M9P0`J8,$`/EB``&IOP0`<2T+`%0A`(#2'R`#U2`,`!'$>&'X(00`D638(/B_
M``%K;/__5*4,`!&E?'V3=B("D7]H)?C%``"PX@,5*@$``+`$`(#2I;A'^2'`
M)9'`#D#YH``_UO4#`"H@!@`T=B("D<$``+#WDP&1(2Q'^<`.0/D@`#_6(```
MD.$#%ZH``""1C0``E(`%`+1S(@*1P0``L"$81_E@#D#Y(``_UL```+``K$?Y
M```_UI1R1_GA-T#Y@`)`^2```,H@!@"UX`,5*O-30:GU6T*I]QM`^?U[QZC`
M`U_6P```L-,``-``0$?Y```_UF(B`I%`#`#Y``0`M,$``+#5``"PU@``L"$4
M1_D@`#_6H"9'^<%21_D``$"Y(``_UA_<*#F8__\7P0``L,`.0/DAY$?Y(``_
MUO4#`"K+__\7P`I`^6```+16"`"4TO__%^$#%ZH@``"0`$`>D5D``)3`"@#Y
M@/G_M$X(`)3*__\7!02`TK'__Q?!``"P(`"`4B'P1OD@`#_6P```L`!@1_D`
M`#_67R0#U1T`@-(>`(#2Y0,`JN$#0/GB(P"1Y@,`D<```+``R$?YPP``L&.(
M1_G$``"0A-Q&^4+__Y=)__^7P```D`!L1_E```"T0?__%\`#7]8?(`/5'R`#
MU1\@`]7```"P```"D<$``+`A``*1/P``Z\```%3!``"0(?1&^6$``+3P`P&J
M``(?UL`#7];```"P```"D<$``+`A``*1(0``RR+\?]-!#(&+(?Q!D\$``+3"
M``"00NQ'^6(``+3P`P*J``(?UL`#7]8?(`/5_7N^J?T#`)'S"P#YTP``L&`"
M0CE``0`UP0``D"$`1_F!``"TP```L``$0/D@`#_6V/__ER``@%)@`@(Y\PM`
M^?U[PJC``U_6'R`#U1\@`]7<__\7'R`#U1\@`]4?(`/5_7N[J?T#`)'S4P&I
M(`<`M/=C`ZGW`P"JP```D/DC`/D`V$?Y&0!`^9D&`+3U6P*I]@,!JA4`@%+@
M`D`Y'_0`<0080'H!`P!4,P-`^?,!`+38``"0M7Y`D_0#&:H8.T?YX@,5JN$#
M%ZK@`Q.J``,_UH```#5@:G4X'_0`<2`"`%23CD#X\_[_M?5;0JGW8T.I^2-`
M^>`#$ZKS4T&I_7O%J,`#7];U`Q>JH!Y`.!_T`'$$&$!ZH?__5+4"%TOC__\7
ME`(9R[4&`)%S`A6+E/Y#D]0"`+G@`Q.J\U-!J?5;0JGW8T.I^2-`^?U[Q:C`
M`U_6$P"`TNC__Q<3`(#2]V-#J?DC0/GD__\7'R`#U1\@`]7]>[*I_0,`D?=C
M`ZG7``"0X7)'^2(`0/GB;P#Y`@"`TL```+3S4P&I\P,`J@$`0#E!`0`U\U-!
MJ>!R1_GA;T#Y``!`^2```,J@"P"U]V-#J?U[SJC``U_6P0``D"$(1_D@`#_6
M]`,`JF#^_[38``"0]5L"J=8``)#Y:P2IV0``D-:R1_D8ZT;Y.2-'^>`#%*K`
M`C_6H`8`M`%,0#D53`"1/[@`<6$``%2A!D`Y`?__-`!,0#D?N`!Q``<`5.`#
M$ZH``S_6^@,`JN`#%:H``S_60`,`"P`(`!$`?$"3(`,_UL8``)#E`Q6J`@"`
MDO4#`*K&[$;Y(0"`4N0#$ZH#``#P8X`<D<``/];#``"0X0,5JN)C`9$``(!2
M8_A&^6``/]8?!``QH```5.!K0+D`#!02'Q!`<>`#`%3!``"0X`,5JB'X1_D@
M`#_6P0``D.`#%:HAJ$?Y(``_UN`#%*K``C_6P/G_M1\@`]7!``"0X`,4JB%<
M1_D@`#_6P0``D.`#$ZHAC$?Y(``_UO-30:GU6T*I^6M$J:G__Q>@!D`Y'[@`
M<>'X_U2@"D`Y(/?_-,3__Q?@`Q6JD___E^3__Q?```"0\U,!J0!@1_GU6P*I
M^6L$J0``/];]>[6IX0,`JOT#`)'S4P&ITP``D/0#`*IC<D?YXJ,`D0``@%)D
M`$#YY%<`^00`@-+#``"08YQ'^6``/];@`0`UX3M`N0(`E%(A#!02/Q!`<200
M0GI@`0!4<W)'^>)70/EA`D#Y00`!RL$!`+7S4T&I_7O+J,`#7]8``(!2]___
M%\(``)#@`Q2J00"`4D)T1_E``#_6'P``<>`7GQKO__\7P```D`!@1_D``#_6
M_7N^J<$``)#]`P"1(>A&^?,+`/GS`P"J(``_U@($`-%B`@*+?P("ZZ,``%0T
M```40@0`T7\"`NL``@!40`!`.1^\`'%@__]4?P("ZX(%`%1"!`#1?P("ZP`!
M`%0?(`/50`!`.1^\`'$@`@!40@0`T7\"`NMA__]48`)`.1^\`'%`!`!4P0``
MD````/#S"T#Y`*`<D?U[PJ@P6$?Y``(?UD``0#D?O`!Q@0``5$($`-%_`@+K
M8___5$(`$\L``(#200@`D3\$0/%(`0!4P```L`2@`I'@`P2JQ```D$($`)'A
M`Q.JA"A'^0,`@M*``#_6\PM`^?U[PJC``U_6?P("ZV']_U3=__\7P0``D```
M`/#S"T#Y`$`;D?U[PJ@P6$?Y``(?U@P*@M+_8RS+PP``D/U[`*G]`P"18_Q&
M^?-3`:G3``"0]5L"J?8C`9'U`P"J8G)'^?=C`ZGW`P&J0`!`^>`G"/D``(#2
MX0,6J@```/#B_X'2`,`<D6``/]8?``!Q30<`5`,$`%'!``"0(21'^<+*8S@X
M`$"Y`@0`-2,%`#1T?$"3PP``D.(#%*K@`Q:J8]1'^>$%@%)@`#_6(`0`M,$`
M`)#@`Q@J(5!'^2``/];$``"0XP,4JN(#%JKA`Q6JA.!'^8``/]9S<D?YX2=(
M^6`"0/D@``#*``0`M0P*@M+]>T"I\U-!J?5;0JGW8T.I_V,LB\`#7];C`P`J
MX06`4N`#%JIT?$"3PP``D.(#%*ICU$?Y8``_UD#\_[4?(`/5P0``D.`#&"HA
M4$?Y(``_UL,``)#B`Q>JX0,5JF,T1_E@`#_6X?__%\```)``)$?Y&`!`N?/_
M_Q?```"0`&!'^0``/];]>[FI_0,`D?-3`:G4``"0\P,`JO5;`JGU`P&J]V,#
MJ=@``)#Y:P2I(@!`.8%R1_E?]`!Q&.M&^2(`0/GB-P#Y`@"`TK46E9K@`Q6J
M``,_UO<#`*KADP&1X`,3JF3^_Y=`"`"T]@,`J@`#/];_`@#K"0<`5/AG@+G9
M``"0&/-]TV`"0#D?]`!Q!!A`>@`-`%3C`Q.J8AQ`.%_T`'%$&$!ZH?__5&,`
M$\MC?$"3.=M'^<$``)#@"@"1(2!'^0```XLW`T#Y(``_UN!J./C``@"TXV>`
MN>`#$ZHB`T#Y`11`.$-X8_@_]`!Q)!A`>F$``#G```!4`A1`.&(<`#A?]`!Q
M1!A`>H'__U2A!X!2``"`TF$4`#BB:F`X8F@@.``$`)&B__\UE')'^>$W0/F`
M`D#Y(```RF`(`+7S4T&I]5M"J?=C0ZGY:T2I_7O'J,`#7]8!`(#2HFIA.,)J
M(3@A!`"1HO__-?#__Q?9``"0^RL`^2#;1_D;`$#Y8`-`^<`%`+3@`QNJ%@"`
M4A\@`]4!C$#XX@,6*M8&`!&A__^U0`P`$0!\?9/!``"P(HA`N:("`#4B`(!2
M(H@`N<$``)`A($?Y(``_UOH#`*I`!`"TPP``D-A^?9/A`QNJX@,8JF/@1OE@
M`#_6(-M'^1H``/G`!@`17]L@^/9G`+G[*T#YH?__%\(``)#A`P"JX`,;JD)4
M1_E``#_6^@,`JB';1_D@``#Y@`$`M-A^?9/Q__\7`P"`TI___Q<``H#2%@"`
M4MK__Q?```"0^RL`^0!@1_D``#_6^RM`^;3__Q<?(`/5_7N^J?T#`)'S4P&I
MU```D-,``)"4)D?Y<U)'^8`"0+E@`C_6@`)`N6`"/];"``"0Q```D",``/`!
M``#P0A!'^6,@&)&$F$?Y(0`=D8``/]:``D"Y8`(_UL8``)`$``#P\U-!J83`
M*9']>\*HXP,$JM"\1_D"``"P`0``\$+`-Y$A@!V1!0"`4@`"']8?(`/5_7N_
MJ<```)#!``"0_0,`D0`D1_DA4$?Y``!`N2``/];$``"0P@``D/U[P:@C``#P
M0A!'^6,@&)&0F$?Y`0``\"$`'9$``A_6'R`#U1\@`]4,"H32_V,LRP`(@M+]
M>P"I_0,`D?-3`:G4``"0\^,`D?5;`JGV8R"+%0"`TH!R1_D!`$#YX2<0^0$`
M@-+```"0`!Q'^0``/];D`P`JQ@``D"(`@M(A`(!2X`,3JL;L1OD%``#P`P``
M\*7@'9%C`!Z1P``_UL,``)#@`Q.JX0,6J@(`@M)C_$;Y8``_U@`"^#?!``"0
M\P,`J@`$`!$A($?Y`'Q`DR``/];U`P"J``$`M,,``)!S?D"3X0,6JN(#$ZIC
MV$;Y8``_UK]J,SB4<D?YX2=0^8`"0/D@``#*``$`M>`#%:H,"H32_7M`J?-3
M0:GU6T*I_V,LB\`#7];```"0`&!'^0``/]8?(`/5'R`#U;S__Q<,'H+2_V,L
MR_U[`*G]`P"1^6L$J=H``)!"<T?Y\U,!J?,#`:KU6P*IX9,!D?4#`*I#`$#Y
MXW<(^0,`@-(```#P`$`>D5;]_Y?T`P"JP@``D.`#%:KA!8!20L1'^4``/]9`
M`@"TX0,5J@```/``@!Z1T/[_E^`#%:I:<T?YXG=(^4$#0/E!``'*(0\`M0P>
M@M+]>T"I\U-!J?5;0JGY:T2I_V,LB\`#7];!``"0]V,#J>`#%:HAZ$;Y%P``
M\"``/];X`P`JP@``D.`#$ZKAPAZ10N1&^4``/];S`P"J0`P`M!D``/#VHP.1
M.:,<D?LK`/D;``#P>T,;D1\@`]5@`D`YP`<`-/0``+3"``"0X0,3JN`#%*I"
M@$?Y0``_UJ`%`#3!``"0X`,3JB'H1OD@`#_6`@0`4>,#`*I@PB*+8<IB.#^\
M`'$A`0!4'R`#U>,#`BI"!`!1'P``.6#"(HMARF(X/[P`<4#__U0`!P`1`P`#
M"W_\/W',`P!4QP``D`(`@M(A`(!2Y`,3JN?L1OGF`Q6JY0,9JN`#%JH#``#P
M8^`>D>``/];#``"0XJ,!D>$#%JH``(!28_A&^6``/]:@```UX'M`N0`,%!(?
M($!QH`(`5,(``)#APAZ1``"`TD+D1OE``#_6\P,`JJ#X_[7W8T.I^RM`^9S_
M_Q>4``"T@`)`.1^X`'&```!4\P,;JB,`@%+6__\7@`9`.<#]_S3[__\7P@``
MD.`#%JHA`(!20G1'^4``/];@_/\UX0,6J@```/``@!Z16_[_E\$``)#@`Q:J
M(5A'^2``/];W8T.I^RM`^8;__Q?W8T.I?___%\```)#W8P.I`&!'^?LK`/D`
M`#_6`@!`.>$#`*K"```T(00`D5^\`'$`$(&:(@!`.8+__S7``U_6'R`#U1\@
M`]6```"T`0!`.4$``#2=_?\7P0``D````/``0!N1,%A'^0`"'];]>[>I(0``
M\"$@&)']`P"1\U,!J=0``)#S<P&1@W)'^?5;`JG6``"0]V,#J14``/"U`A^1
M^6L$J=;:1_EF`$#YYD<`^08`@-(F'$&IYA\&J2040JGD%P>I(6!`>>$#`7GA
M`Q.JX`,5JIG\_Y<``@"TP@)`^>-?@+E`#`.+`01`^4%X(_CA_O^T'R`#U0$(
M0/D!!`#Y`"``D:'__[7A`Q.JX`,5JHK\_Y=`_O^UU@``D!4``/"U0A^1UMI'
M^>$#$ZK@`Q6J@OS_E^`!`+3"`D#YXU^`N4`,`XL!!$#Y07@C^.'^_[0!"$#Y
M`00`^0`@`)&A__^UX0,3JN`#%:IT_/^78/[_M=8``)`5``#PM6(?D=;:1_GA
M`Q.JX`,5JFS\_Y?@`0"TP@)`^>-?@+E`#`.+`01`^4%X(_CA_O^T`0A`^0$$
M`/D`(`"1H?__M>$#$ZK@`Q6J7OS_EV#^_[76``"0%0``\+6B'Y'6VD?YX0,3
MJN`#%:I6_/^7X`$`M,("0/GC7X"Y0`P#BP$$0/E!>"/XX?[_M`$(0/D!!`#Y
M`"``D:'__[7A`Q.JX`,5JDC\_Y=@_O^UU@``D!4``/"WPA^1UMI'^>$#$ZK@
M`Q>J0/S_E^`!`+3"`D#YXU^`N4`,`XL!!$#Y07@C^.'^_[0!"$#Y`00`^0`@
M`)&A__^UX0,3JN`#%ZHR_/^78/[_M;<``/`6``#0U@(@D??:1_GA`Q.JX`,6
MJBK\_Y?@`0"TX@)`^>-?@+E`#`.+`01`^4%X(_CA_O^T`0A`^0$$`/D`(`"1
MH?__M>$#$ZK@`Q:J'/S_EV#^_[6W``#P%@``T-A"'I'WVD?YX0,3JN`#&*H4
M_/^7X`$`M.("0/GC7X"Y0`P#BP$$0/E!>"/XX?[_M`$(0/D!!`#Y`"``D:'_
M_[7A`Q.JX`,8J@;\_Y=@_O^UN```\!<``-#Y0B"1&-M'^>$#$ZK@`QFJ_OO_
ME^`!`+0"`T#YXU^`N4`,`XL!!$#Y07@C^.'^_[0!"$#Y`00`^0`@`)&A__^U
MX0,3JN`#&:KP^_^78/[_M;D``/`8``#0&H,@D3G;1_GA`Q.JX`,:JNC[_Y?@
M`0"T(@-`^>-?@+E`#`.+`01`^4%X(_CA_O^T`0A`^0$$`/D`(`"1H?__M>$#
M$ZK@`QJJVOO_EV#^_[6Z``#P&0``T#G#()%:VT?YX0,3JN`#&:K2^_^7X`$`
MM$(#0/GC7X"Y0`P#BP$$0/E!>"/XX?[_M`$(0/D!!`#Y`"``D:'__[7A`Q.J
MX`,9JL3[_Y=@_O^UN@``\!D``-`Y@QZ16MM'^>$#$ZK@`QFJO/O_E^`!`+1"
M`T#YXU^`N4`,`XL!!$#Y07@C^.'^_[0!"$#Y`00`^0`@`)&A__^UX0,3JN`#
M&:JN^_^78/[_M>$#$ZH```#0```AD:G[_Y?A`P"J8```M`"#()$J_?^7X0,3
MJ@```-``8"&1H?O_E^$#`*J```"T````T`!@&Y$A_?^7X0,3J@```-``P"&1
MF/O_E^$#`*I``@"TP$(>D1G]_Y>@PA^1`0``T"&@(I$5_?^7E')'^>%'0/F`
M`D#Y(```RN`#`+7S4T&I]5M"J?=C0ZGY:T2I_7O)J,`#7];A`Q.J````T```
M(I&!^_^7X0,`JH```+3@0B"1`OW_E^G__Q<!*HC2XA-'^$'JJ_)AB,GRH2CH
M\E\``>M!_/]4X9-'>,"IAU(_``!KP?O_5.!"()'A[P&1\_S_E]K__Q>@``#P
M`&!'^0``/]8?(`/5_7N]J?T#`)'S4P&ILP``\-0``)!A<D?Y@!)`N2(`0/GB
M%P#Y`@"`TA\$`#$@`0!4<W)'^>(70/EA`D#Y00`!RB$"`+7S4T&I_7O#J,`#
M7];ADP"1````T`!`()%1^_^7X0,`J@``@%*A``"T(`!`.1_``'$$&$!ZX`>?
M&H`2`+GL__\7H```\`!@1_D``#_6_7N_J:```/#]`P"1``1'^0``/]:A``#P
M(81'^2``/]9```"T``!`^?U[P:C``U_6_7N[J?T#`)'U6P*IM0``\!8``-#W
M8P.IV,(BD>$3`9&W<D?Y\U,!J?0#`*KB`D#YXB<`^0(`@-+@`QBJ*?O_EX``
M`+0!`$`Y\P,`JJ$!`#6U<D?YX2=`^:`"0/D@``#*H`8`M>$#%*K`PB*1\U-!
MJ?5;0JGW8T.I_7O%J)[\_Q>B``#PX0,4JD+H1_E``#_60`$`M.$G0/G@`D#Y
M(```RJ`$`+7S4T&I]5M"J?=C0ZG]>\6HP`-?UK8``/#@`Q2JUNI&^<`"/];U
M`P"JX`,3JL`"/]:A``#PH`(`BP`(`)$A($?Y(``_UJ<``/#F`Q.J(0"`4N0#
M%*KG[$;Y\P,`J@4``-`#``#0I<`>D6/@'I$"`("2X``_UN$G0/G@`D#Y(```
MRH```+7A`Q.JX`,8JL___Q>@``#P`&!'^0``/]8,.)#2_V,LRP,"D-+]>P&I
M_4,`D?MS!JG<``"0@D,`D?5;`ZFV``#P^P,`JD:<0*GF'PFIX&,CBTHL0JGS
M4P*I2"1#J?=C!*D8``#01!1$J?EK!:GY,P*11AQ%J>:?"JG4<D?YZB\,J4P,
M0/F!`D#Y`=0`^0$`@-)",$#YX0,9J@!#'I'L4P#YXE\`^>@G#:GD%PZIP_K_
MEX```+0!`$`Y\P,`JH$H`#6@``#P``1'^0``/]:A``#P(81'^2``/]:`(@"T
M%P!`^5<B`+2A``#PX`,7JB'H1OD@`#_6`/A_TZ$``/#A.P#YH0``\``$`)$A
M($?Y(``_UOH#`*KD`D`Y!"@`-*```/`#``#0]0,:JG0@(Y$3[$;YX#\`^1\@
M`]7@`Q6JXP,4J@(`@)(A`(!28`(_UK4*`)'D'D`X)/__-0```-#T(P.1`&`;
MD0,``!2`AD#XH`L`M.$#&:J1^O^7\P,`JF#__[0!`$`Y(?__-$7[_Y?@_O\T
MH0``\.`#$ZHA6$?Y(``_UO<#`*K@"0"TX#M`^14``-`4Z$;YX`,7JH`"/];S
M`P"JX`,:JH`"/]:A``#P<P(`"W,2$!$A($?Y<WY`D^`#$ZH@`#_6]`,`JJ@`
M`/`"`("2(0"`4N<#&JH([4;YY`,7JJ6B')$&``#0`P``T,9`(Y%C8".1``$_
MUJ(``/#@`Q2J`3B`4D+\1_E``#_6'P0`,>$``%2@``#P`/1'^0``/]8%`$"Y
MOT0`<8$:`%2C``#PXL,#D>$#%*H``(!28YQ'^6``/];Z`P`J0`8`-*```/"E
M``#P8P-`^0(``-``#$?YY`,4JJ5\1_E"H"21``!`^2$`@%(3`(#2H``_UM9R
M1_D``I#2X&,@BP'40/G``D#Y(```RD`O`+7@`Q.J##B0TOU[0:GS4T*I]5M#
MJ?=C1*GY:T6I^W-&J?]C+(O``U_6M```\/-#`I$5`(!2E%I'^7?:=?BW`0"T
MX`)`.6`!`#2U!@`1X`,7JN7Z_Y<@__\TX`,7JH`"/];W`P"J8/3_M7?:=?BW
M_O^U%P"`TI___Q?@`T&Y``P4$A\00'&!^?]4H```\/<+0;D`!$?Y```_UO\"
M`&O!^/]4X`-!N0`@`!(?``=Q0?C_5*$``/#@`Q.J(2!'^2``/];S`P"J`0``
MT"``)I'A`QFJ#/K_E\`4`+2A``#P=P-`^2%81_D@`#_6X0,`JN`#%ZJ=_/^7
M]P,`JJ`3`+2A``#PX`,7JB'H1OD@`#_6X@,`JA\,`'%M`@!4XCL`^:(``/``
M?$"3`0``T$*`1_D`$`#1(2`FD>`"`(M``#_6(`$`->([0/E?$`!Q8!X`5$(4
M`%'@RF(X'[P`<>`=`%0?(`/5@!-`N1\$`#%@$`!4&P``T&`1`#1@0R"1`0``
MT"&@(I%E^_^7H```\+<``/`;``#0&0``T``<1_DYXR:1```_UN8#`"JH``#P
M9\,ID:6B')'D`Q2J".U&^>`#$ZH#``#0`@"`DF.@)I$A`(!2``$_UO?V1_D6
M```4X`(_U@``0+D?1`!Q(0,`5*```/!:!P`1`!Q'^0``/];F`P`JJ```\&'#
M*9'A`P#YYP,:*@CM1OFEHAR1Y`,4JN,#&:K@`Q.J`@"`DB$`@%(``3_6H@``
M\.`#$ZH!.(!20OQ'^4``/]8?!``QH/S_5*$``/#@`Q2J(:A'^2``/];A`Q.J
M`$,>D2W[_Y?@`Q.J;O[_EU[__Q>T``#P\Z,"D14`@%*46D?Y8-IU^(`!`+3A
M`QFJM08`$9SY_Y=@__^T`0!`.2'__S2``C_6]P,`JB#<_[5@VG7XP/[_M:$`
M`/"@`8#2(2!'^2``/];Z`P"J!@``T*```/#7`".19`J`4N`[`/GB_O\7H```
M\*8``/!C`T#YY`,4J@`,1_D"``#0QGQ'^4*@(Y$``$#Y(0"`4A,`@-+``#_6
M-?__%T/^_Y<!`I#2X&,ABP'40/F``D#Y(```RL`5`+7@`Q.JH0``\/U[0:D,
M.)#2\U-"J?5;0ZGW8T2I^6M%J?MS1JDP6$?Y_V,LBP`"']:@``#PX#\`^<[^
M_Q=W`T#Y8___%QL``-#A`QFJ8$,@D6#Y_Y>@``"T``!`.1_``'$$&$!ZH0L`
M5)\3`+FB``#PX`,7J@$`@%(;``#00MQ'^4``/];Y`P`JX.W_-*,``/"[``#P
M0@"`4B$"@))W1$?Y^N,&D>`"/]9\TT?YX0,:JN`#&2K"`(#2@`,_UN#C1CF`
M```UX.=&.1\,`7$`"P!4HP``\`$`@-("`(!2X`,9*F-$1_E@`#_6H```\`#P
M1_D``#_6_`,`JJ$``/![TT?Y-TQ'^04``!3B`P`JX0,:JN`#'*K@`C_6X0,:
MJN`#&2H"`)#28`,_UA\``''L_O]4H0``\.`#&2KYPP61^R,&D2%D1_GZ`QFJ
M(``_UOL[`/FB``#PX`,9JN$#'*K\`QNJ0L!'^?O#!I%``#_6X#]`^0,``-!Y
M(".1%^Q&^1\@`]7@`QRJ1!=`.)P+`)'C`QFJ`@"`DB$`@%+@`C_6?P,<ZP'_
M_U3F.T#Y_\,&.:6B')'D`Q2JX`,3J@<``-`#``#0Y\`ID6-@)I$"`("2(0"`
M4N`"/]91__\7(`"`4H`3`+D9__\7>P=`^5OB_[2A``#PX`,;JB'H1OD@`#_6
M'PP`\8GA_U2B``#P`!``T6`#`(L!``#00H!'^2%`)I%``#_6'P``<?<2FYH"
M__\7X.M&.1\$`7'A]/]4X.]&.1\,`7&!]/]4X/-&.1\@`7$A]/]4X/=&.1\4
M`7'!\_]4X`,9*D(`@%(A!X"2X`(_UN$#&JK@`QDJ(@6`TH`#/]:H``#PY@,:
MJJ6B')'D`Q2J".U&^>`#$ZH'``#0`P``T.?`*9%C8":1`@"`DB$`@%(``3_6
M&O__%Z```/``8$?Y```_UOU[N:G]`P"1\U,!J;0``/"S``#P]5L"J;8``/#Y
M:P2IF29'^?=C`ZGWDP&1P7)'^7A21_DB`$#YXC<`^0(`@-(@`T"Y``,_UO4#
M`*H@`T"Y``,_UN(#`*JCPD(Y````T.$#%ZH`P!^10\0".:GX_Y>```"T`0!`
M.3_$`''`#0!4\?O_EYDF1_EX4D?Y(`-`N0`#/]:D``#P`0``T&,`@%(A0">1
MA&A'^2(`@%*``#_6]0,`JL`!`+0@`T"Y``,_UJ$*0/FC``#P`@``T$)@)Y%C
M-$?Y(0!`^6``/]:@"D#Y``!`^0`,0+E`#;`WFB9'^=4``)!Y4D?Y0`-`N2`#
M/]:D``#P`0``T&,`@%(A@">1A&A'^2(`@%*``#_6^`,`JB`"`+3A`Q>J````
MT`"`'I'[*P#Y=_C_E_L#`*I``T"Y>PD`M"`#/]8!"T#YHP``\.(#&ZIC-$?Y
M(0!`^6``/];[*T#YN2("D90F1_ES4D?Y@`)`N6`"/];X`P"J@`)`N6`"/]:C
M``#P(@"`4@$``-`AH">18Y!'^6``/];A`P"JHP``\.`#&*H"``#00@`HD6,T
M1_E@`#_6@`)`N6`"/];B`P"JX0,7J@```-``0!Z17\0".4_X_Y<@"P#Y\P,`
MJ@`#`+2B``#P`3B`4N`#$ZI"_$?Y0``_U@$$`!$_!`!Q!(A1>N$%`%36<D?Y
MX3=`^<`"0/D@``#*P`0`M?-30:GU6T*I]V-#J?EK1*G]>\>HP`-?U@`$0#E@
M\O\TD?__%R`'0/E+_?^7(`L`^?,#`*J@_/^UH0``T/LK`/D```"P`"`HD2&4
M1_D@`#_6(`,_UJ`B`I$""T#Y`01`^4``0/DA`$#Y4/G_E_LK0/FV__\7(`-`
MN0`#/]:A"D#YH@``T$*T1_DA`$#Y0``_UI#__Q>@``#0^RL`^0!@1_D``#_6
MM2("D?LK`/FD``#0XP,`*N(#$ZH```"PH09`^0#`*)&$E$?Y(0!`^8``/]8?
M(`/5_7N[J?T#`)'U6P*IM0``T*%R1_GS4P&I]`,`JO<;`/DB`$#YXB<`^0(`
M@-*@!@"T`0!`.6$&`#3>^/^7`0!`.?,#`*K!```T``0`D3^\`'%S$H":`0!`
M.8'__S6W``#PGP(`\?8'GQK@$D"Y'P0`,4`%`%0?``!QX`>?&M8"``IV`0`U
MM7)'^>$G0/F@`D#Y(```R@`&`+7S4T&I]5M"J?<;0/G]>\6HP`-?UH`"0#F@
M_O\THP``T`$``+#@`Q.J(4`CD6,X1_F"`(#28``_UJ#]_S6U<D?YX2=`^:`"
M0/D@``#*@`,`M>`#%*KS4T&I]5M"J?<;0/G]>\6H#?C_%Z$``-````"P`$`;
MD2%81_D@`#_6RO__%P```+#A$P&1`$`@D;_W_Y>@``"T``!`.1_``'$$&$!Z
M80``5/\2`+G1__\7(`"`4N`2`+G6^?\TU___%Z```-``8$?Y```_UO^#"M&H
M``#0XF,`D07@`)$)X`&1Y`,"JOU[`*G]`P"1`7%'^2,`0/GC3P'Y`P"`TJ$`
M0+F$0`"1HX1`^"$(P%J!`!_X8?Q@TV?\:-/G''B2)MQXTR$<"%/&''"2X^!#
MJB$`!JHA``.J@8`?^#\!!>L!_O]410`(D4$`0/E"(`"10P1`^40<0/EC``'*
M03!`^2$`!,HA``/*(_Q?TV$$`:HA?$"203P`^5\`!>MA_O]4`QA`J2HSC]($
M%$&I2E"K\NNS0:DI=)W28OQ;TVW\0M-"%`.JK7D#JJ$`!,HIVZWR(0`&BB$`
M!<IK`0J+(D`BB\'\0M,A>`:J0@`+BP<00/DN?$"2RP$$RHP!"HM"``<+:P$#
MBFL!!,HA``W*3_Q;TVL!!8OO%0*J:P$,BVL!#PM/_$+3(0`"BN)Y`JKLOT*I
M(0`.RG#]6],A``2+$!8+JE%\0)*,`0J+[P$*BR$`#(NL`0+*(0`0"[!]0))M
M_4+3C`$+BJUY"ZJ,`1#*2P`-RHP!#HMK`0&*C`$/BVL!$<HN_%O3:P$0B\X5
M`:KOPT.IC`$."R+\0M.._5O307@!JLX5#*JB`0'*0@`,BJU]0)+O`0J+0@`-
MRFL!#XL0`@J+;@$."XO]0M-L>0RJ0@`1BRL`#,K/_5O3(7Q`DFL!#HI"`!"+
M[Q4.JFL!`<I/``\+:P$-B]']0M/BMT2I+GH.JO#]6],0%@^J0@`*BVL!`HN"
M`0[*:P$0"XQ]0))"``^*\/U"TT(`#,H/>@^J0@`!BZ$!"HMM_5O30@`!BZT5
M"ZK!`0_*</U"TTT`#0LA``N*"WH+JN+#1:G.?4"2(0`.RK']0M,A``R+K/U;
MTXP5#:I"``J+(0`"B^(!"\I"``V*[WU`DD(`#\HL``P++7H-J@$""HM"``Z+
MD/U;TT(``8MA`0W*(0`,BFM]0)(0%@RJ(0`+RE``$`LA``^+XK]&J9']0M,L
M>@RJ#OY;T\X5$*H1_D+30@`*BR$``HNB`0S*0@`0BJU]0))"``W*+@`."S!Z
M$*KA`0J+0@`+B\_]6]-"``&+@0$0RB$`#HJ,?4"2[Q4.JB$`#,I/``\+(0`-
MB^*W1ZG1_4+3+GH.JNO]6]-K%0^J\?U"TT(`"HLA``*+`@(.RD(`#XH0?D"2
M0@`0RBL`"PLO>@^JH0$*BT(`#(MM_5O30@`!B\$!#\HA``N*SGU`DJT5"ZHA
M``[*30`-"R$`$(OBPTBI<?U"TRMZ"ZJL_5O3C!4-JK']0M-"``J+(0`"B^(!
M"\I"``V*[WU`DBP`#`M"``_*`0(*BRUZ#:I"``Z+COU;TT(``8MA`0W*\$]`
M^7%]0)+.%0RJ(0`,BD(`#@N+_4+3(0`1RFQY#*H0`@J+(0`/BZL!#,I._%O3
M(0`0B\X5`JKP4T#YK7U`DFL!`HHA``X+:P$-RD[\0M/.>0*J$`(*BVL!$8N"
M`0[*:P$0BXQ]0)+P5T#Y+_Q;TT(``8KO%0&J0@`,RFL!#PL0`@J+0@`-BR_\
M0M-"`!"+[WD!JFW]6]/P6T#YP0$/RB$`"XK.?4"2K14+J@H""HLA``[*</U"
MT[(!`@L0>@NJ(0`,BT)`+8OK7T#Y(0`*B^H!$,I,_EO32@$"2FT!"8N,%1*J
M0OY"TTH!#HN1`0$+2@$-BTUX$JKB8T#Y+$`LBP$"#<HK_EO3+``,2FL5$:I!
M``F+@D$OBR_^0M-N`0H+[WD1JD(``8OA9T#Y2D$KBZL!#\K,_5O3:P$*2HP5
M#JHJ``F+84$PB]#]0M.2`0(+#GH.JD)`+(OL`0[*2_Y;TXP!`DIK%1*JC4$M
MBTS^0M.2>1*J(0`*B^HS3:EQ`0$+(4`KB\L!$LIK`0%*0@$)BRK^6]-*%1&J
MH@$"BX$!"8LM_D+3;$$OBU`!`@NQ>1&J@0$!B^QS0/E"0"J+2@(1R@O^6]-"
M`0)*:Q40JHP!"8M"0"Z+#?Y"TV\!`0NP>1"J0@`,B^QW0/DA0"N+*P(0RNK]
M6]-A`0%*2A4/JHP!"8LA0#*+3@$""R$`#(OM_4+30D`JB^Q[0/FO>0^J"@(/
MRLO]6]-K%0ZJ2@$"2H(!"8O,_4+3?@$!"XYY#JKL?T#Y(4`KB^L!#LI-03&+
M:P$!2LK_6]-*%1ZJH@$"BX$!"8O-_T+3;$$PBU(!`@NM>1ZJ@0$!B^R#0/E"
M0"J+R@$-RDO^6]-"`0)*:Q42JHP!"8M"0"^+3_Y"TT(`#(OL>1*J<0$!"R%`
M*XNK`0S*80$!2BK^6],A0"Z++OY"TTH5$:K1>1&J[[M0J5`!`@M"0"J+B@$1
MR@O^6]-*`0)*:Q40JDU!+8OO`0F+P@$)BR$`#XL._D+3;P$!"]!Y$*JB`0*+
M(4`KB^K]6],K`A#*2A4/JFL!`4KMCT#Y3@$""VQ!+(M"0"J+H0$)B\O]6]/M
M_4+3:Q4.JJ]Y#ZJ!`0&+[)-`^6T!`0L*`@_*(4`KBT(!`DJ,`0F+0D`QBZK]
M6]/1_4+32A4-JBYZ#JI"``R+[)=`^5$!`@OK`0[*0D`JBV$!`4J+`0F+(4`P
MBRS^6].P_4+3C!41J@UZ#:HA``N+ZYM`^9`!`0O*`0W*(4`LBTH!`DIB`0F+
M2D$OBPO^6],O_D+3:Q40JDH!`HOB>1&J\9]`^6\!"@NL`0+*2D$KBXP!`4HA
M`@F+C$$NBQ'^0M/N_5O3C`$!B\X5#ZHA>A"J\*-`^=$!#`M+``'*C$$NBVL!
M"DH*`@F+:T$MB_#]0M,M_EO3#WH/JJT5$:IK`0J+\*=`^:H!"PLN``_*:T$M
MB\X!#$H,`@F+PD$BBU#]6],N_D+30@`,B]%Y$:H0%@JJ[*M`^5``$`OB`1'*
M2P`+2HD!"8M"_4+384$ABP[^6]-+>`JJ(0`)B\X5$*HN``X+*@(+JN&O0/EI
M`1$*2@$0B@+^0M-*`0FJC)N7TFSCL?)0>!"J(0`,BTI!+XO/_5O3:0$0JDH!
M`8OO%0ZJX;-`^4\!#PL"`@L**0$.BBD!`JK*_4+33GD.JB$`#(LI03&+[?U;
MTP("#JHI`0&+K14/JD(`#XKAMT#Y+0$-"\D!$`I"``FJ(0`,B^G]0M-"0"N+
MJ_U;TR]Y#ZI"``&+:Q4-JDL`"PO!`0^JXKM`^>H!#@HA``V*J?U"TR$`"JHM
M>0VJ0@`,BR%`,(MP_5O3Z@$-JB$``HL0%@NJXK]`^3``$`M*`0N*H0$/"FG]
M0M-*`0&J*WD+JD$`#(M*02Z+#OY;TZD!"ZI*`0&+SA40JF(!#0KAPT#Y3@$.
M"RD!$(H*_D+3*0$"JE!Y$*HA``R+*4$OB\_]6]-B`1"J*0$!B^\5#JKAQT#Y
M+P$/"T(`#HH)`@L*0@`)JB$`#(O)_4+30D`MB^W]6],N>0ZJ0@`!BZT5#ZI-
M``T+`0(.JN++0/G*`1`*(0`/BNG]0M,A``JJ+WD/JD(`#(LA0"N+J_U;T\H!
M#ZHA``*+:Q4-JN+/0/DK``L+2@$-BN$!#@JI_4+32@$!JBUY#:I!``R+2D$P
MBW#]6]/I`0VJ$!8+JDH!`8LI`0N*X=-`^4H!$`NP`0\*8OU"TRD!$*I+>`NJ
M(0`,BRE!+HM._5O3H@$+JBD!`8O.%0JJX==`^2X!#@M"``J*:0$-"D(`":HA
M``R+2?U"TT)`+XO/_5O3,'D*JD(``8OO%0ZJ3P`/"V$!$*KBVT#Y"0(+"B$`
M#HK*_4+3(0`)JDYY#JI"``R+(4`MB^G]6],*`@ZJ*14/JB$``HOBWT#Y(0`)
M"TH!#XK)`1`*2@$)JNG]0M,O>0^J0@`,BTM!*XLM_%O3K14!JLD!#ZIK`0*+
M*0$!BN+C0/EK`0T+[0$."BK\0M,I`0VJ07D!JD(`#(LI03"+;?U;TRD!`HNM
M%0NJX@$!JNKG0/DI`0T+0@`+BBT`#PI"``VJ2@$,BVW]0M-"0"Z++OU;TZUY
M"ZI"``J+SA4)JDX`#@LJ``VJ(OU"TTH!"8I">`FJL`$!"NLG7:E*`1"J2D$O
MB\_]6]/O%0ZJT/U"TVL!#(LI`0R+2@$+BZL!`JI/`0\+:P$.BDH`#0H.>@ZJ
M:P$*JNK]6]-A02&+2A4/JB$`"8M)``ZJ(0`*"]`!`@KJ\T#Y*0$/BBD!$*KK
M_4+32@$,BRE!+8MO>0^J*0$*BRW\6]/+`0^JZO=`^:T5`:HP_$+3+0$-"VL!
M`8KI`0X*`7H!JFL!":I)`0R+Z@$!JC$`#PI*`0V*2@$1JF)!(HM*02Z+J_U;
MTZ[]0M-"``F+:Q4-JLUY#:KI.U^I<`$""TM`*XLB``W*0@`+2LLZF-)+3+GR
M0D`OBP_^0M,L`0R+"?Y;TTH!#(LI%1"J,@$*"\X!"XOP>1"J0@`.BTS^6]-)
M02F+C!42JJH!$,KN`T'YD0$""TD!"4I"0"R+R@$+BR%!(8M._D+3*?Y;T])Y
M$JHI%1&J(0`*BPP"$LKJ!T'Y+P$!"XP!`DHA0"F+2@$+BXQ!+8OB_5O3+?Y"
MT[%Y$:J,`0J+0A0/JDD"$<KJ"T'Y3@`,"R$!`4KM_4+320$+BRI`,(O!_5O3
MKWD/JDH!"8LA%`ZJZ0]!^3``"@N"02*++`(/RH(!`DK-_4+3+`$+BTE`,HL"
M_EO3KGD.JBD!#(M"%!"J[!-!^5(`"0OM`0[*04$ABZ$!`4J*`0N++4`QBPS^
M0M-!_EO3D'D0JJH!"HLA%!*J[!=!^3$`"@LB02*+R0$0RB(!`DI-_D+3B0$+
MBTQ`+XLB_EO3K7D2JHD!"8M"%!&J[!M!^4\`"0M!02&+"@(-RD$!`4J,`0N+
M*D`NBR[^0M/A_5O3T7D1JDH!#(LA%`^J[!]!^2X`"@LB02*+J0$1RB(!`DJ,
M`0N+24`PB_#]0M/"_5O3#WH/JBD!#(M"%`ZJ["-!^5(`"0M!02&+*@(/RD$!
M`4J*`0N++4`MB\S]0M-!_EO3CGD.JJH!"HLA%!*J["=!^3``"@LB02*+Z0$.
MRB(!`DI-_D+3B0$+BTQ`,8L"_EO3B0$)BT(4$*JL>1*J\2M!^4T`"0M!02&+
MR@$,RD$!`4HQ`@N+*D`OBP_^0M.A_5O3\'D0JDH!$8LA%`VJ\2]!^2\`"@LB
M02*+B0$0RB(!`DHQ`@N+24`NBZ[]0M/B_5O3S7D-JBD!$8M"%`^J\3-!^4X`
M"0M!02&+"@(-RD$!`4HJ`@N++$`LB_']0M/!_5O3+WH/JHP!"HLA%`ZJZC=!
M^3$`#`LB02*+J0$/RBD!`DI"`0N+*D$PB]#]0M,I_EO3#GH.JDH!`HLI%1&J
MXCM!^3`!"@N!02&+[`$.RH$!`4HR_D+33``+BR)`+8L!_EO330`,BR$4$*I"
M>A&J[#]!^3$`#0M)02F+R@$"RDH!"4J)`0N+3$$OBP_^0M,J_EO3C`$)B^]Y
M$*I*%1&JZ4-!^5`!#`NA02&+30`/RJT!`4HA`0N+K4$NBPG^6],N_D+3K0$!
MB\YY$:HI%1"JX4=!^3$!#0N*02J+[`$.RHP!"DHJ``N+@D$BBR'^6]-"``J+
M(101JD(``0L!_D+3[$M!^2%X$*JJ02F+S0$!RDG\6]-C0"^+K0$*2BD5`JJ*
M`0N+*_Y"TTH!`XLI`0V+8WD1JD(`!@L(<4?Y(0`%"V0`!`O'`0<+)0$*"P4(
M`*D$!`&IXT]!^0(!0/EB``+*!Q``^8(``+7]>T"I_X,*D<`#7]:@``"P`&!'
M^0``/];]>[^IH0``L``0@-+]`P"1(2!'^2``/]8?&`#Y)F"$TB5QE=+$GYO2
MPXZ*T@(^G-*FZ*SRI?F]\D07L_)#!J+R0GJX\@84`*D$#`&I`GP"J1]X`+G]
M>\&HP`-?UA\@`]7]>[RI0GQ`D_T#`)'S4P&I%.``D?,#`:KU6P*I]0,`JO8#
M`JKW8P.I!8Q"J0!X0+FD#`(+OP`$ZV.4@YIB=$*+I(H"J6`$`#7?_@!QK08`
M5-8"`5'8?@93%P<`$?=J>M-W`A>+'R`#U6`&0*F`!@"I<P(!D6(.?:F"#@&I
MX`,5JF(.?JF"#@*I8@Y_J8(.`ZF@^_^7?P(7ZX'^_U36&AA+HP``L.$#%ZK@
M`Q2JPGY`DV/81OE@`#_6MGH`N?-30:GU6T*I]V-#J?U[Q*C``U_6HP``L!<(
M@%+W`@!+@,(@B]\"%VMCV$;YU]*7&OA^0)/B`QBJ8``_UJ!Z0+G@`@`+H'H`
MN1\``7&A_?]4U@(72W,"&(O@`Q6J?OO_E\O__Q?W`Q.JW___%Q\@`]4?(`/5
M_7N\J?T#`)'S4P&I\P,!JO0#`*KU6P*I=>(`D>$/@!+W&P#Y8!9`^78J0+EW
M,D"Y`"`#4]8*P%H"!``1]PK`6J'*(#B@PB*+7^``<0T*`%2C``"P`0B`4B(`
M`DL!`(!28SQ'^4)\0)-@`#_6X`,3JES[_Y=__@.I?_X$J7_^!:E_-@#Y=UH.
M*>`#$ZI5^_^780)`^>`#$ZHA_%C3@0(`.6$"0/DA_%#3@08`.6$"0/DA_$C3
M@0H`.6$"0/F!#@`Y809`^2'\6-.!$@`Y809`^2'\4-.!%@`Y809`^2'\2-.!
M&@`Y809`^8$>`#EA"D#Y(?Q8TX$B`#EA"D#Y(?Q0TX$F`#EA"D#Y(?Q(TX$J
M`#EA"D#Y@2X`.6$.0/DA_%C3@3(`.6$.0/DA_%#3@38`.6$.0/DA_$C3@3H`
M.6$.0/F!/@`Y81)`^2'\6-.!0@`Y81)`^2'\4-.!1@`Y81)`^2'\2-.!2@`Y
M81)`^8%.`#FA``"P\U-!J?5;0JGW&T#Y_7O$J#"H1_D``A_6HP``L`$'@%(B
M``)+`0"`4F,\1_E"?$"38``_UK?__Q<?(`/5_7N\J?T#`)'S4P&IM```L)3B
M+)'U6P*IM0``L+7"+)&4`A7+]@,`*O=C`ZGW`P&J^`,"JI3^0Y.@\?^7=`$`
MM!,`@-(?(`/5HWIS^.(#&*IS!@"1X0,7JN`#%BI@`#_6GP(3ZR'__U3S4T&I
M]5M"J?=C0ZG]>\2HP`-?UA\@`]7``U_6'R`#U1\@`]4?(`/5HP``T&,$0/F6
M\?\77R0#U?U[OZG]`P"1_7O!J,`#7]8!``(``````"]T;7``````+@``````
M``!005)?5$U01$E2````````5$U01$E2``!414U01$E2`%1%35``````5$U0
M``````!54T52`````%5315).04U%```````````E<R\E<P```"\`````````
M+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@``
M````26YT97)N86QS.CI005(Z.D)/3U0`````97AE```````O<')O8R\E:2\E
M<P``````4$%27U1%35```````````%!!4E]04D]'3D%-10`````Z````````
M`"5S)7,E<P``4$523#5,24(``````````%!%4DQ,24(`4$523#5/4%0`````
M`````%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$``````!0
M05)?0TQ%04X`````````4$%27T1%0E5'`````````%!!4E]#04-(10``````
M``!005)?1TQ/0D%,7T1%0E5'``````````!005)?1TQ/0D%,7U1-4$1)4@``
M``````!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@``````````
M4$%27T-,14%./0```````#$`````````3$1?3$E"4D%265]0051(`%-94U1%
M30``)3`R>`````!P87(M`````"5S)7,E<R5S```````````E<SH@8W)E871I
M;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE
M:2D*````````)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F
M92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI
M"@```````%!!5$@`````<&%R;``````N<&%R`````"5S)7-C86-H92TE<R5S
M```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E<P``````````&```
M``````!P97)L`````#``````````4$%2.CI086-K97(Z.E9%4E-)3TX`````
M,2XP-3(```!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``````
M````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y
M("5S(&9A:6QE9"`H97)R;F\])6DI"@``````````+64````````M+0``````
M`&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII
M9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?
M7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1P87)?=&5M<"P@)'!R;V=N86UE
M+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%2
M7T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ
M0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I
M;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M
M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN
M9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?
M=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D
M7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*
M5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE
M.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@
M/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT
M("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*
M<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@
M=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR
M;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I
M;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@
M)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@
M<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@
M?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F
M26YT97)N86QS.CI005(Z.D)/3U0["B1005)?34%'24,@/2`B7&Y005(N<&U<
M;B(["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6
M>U!!4E]$14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D
M7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H
M)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I
M+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@
M.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*
M;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!
M4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G/#IR87<G+"`D<')O9VYA;64@
M;W(@;&%S=#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY
M("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D;6%G:6-?<&]S.PII9B`H
M)'-I>F4@/#T@)&-H=6YK7W-I>F4I('L*)&UA9VEC7W!O<R`](#`["GT@96QS
M:68@*"AM>2`D;2`]("1S:7IE("4@)&-H=6YK7W-I>F4I(#X@,"D@>PHD;6%G
M:6-?<&]S(#T@)'-I>F4@+2`D;3L*?2!E;'-E('L*)&UA9VEC7W!O<R`]("1S
M:7IE("T@)&-H=6YK7W-I>F4["GT*=VAI;&4@*"1M86=I8U]P;W,@/CT@,"D@
M>PIS965K(%]&2"P@)&UA9VEC7W!O<RP@,#L*<F5A9"!?1D@L("1B=68L("1C
M:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@
M<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["B1M86=I8U]P;W,@
M*ST@)&D["FQA<W0["GT*)&UA9VEC7W!O<R`M/2`D8VAU;FM?<VEZ93L*?0IL
M87-T(&EF("1M86=I8U]P;W,@/"`P.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M
M(#0L(#`["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@)&UA9VEC7W!O
M<R`M(#0@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,#L*)&1A=&%?<&]S(#T@=&5L
M;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@
M("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)
M3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@
M-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L
M;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA
M;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD
M77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I
M(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L
M("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*
M:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\
M86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L
M("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M
M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N
M86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO
M/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F
M:6QE;F%M92`](%]S879E7V%S*"(D8F%S96YA;64D97AT(BP@)&)U9BP@,#<U
M-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD<F5Q
M=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD36]D=6QE0V%C:&5[)&9U;&QN86UE
M?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL
M;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@
M*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E
M9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`](&1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1M;V1U;&5](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]
M("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y]
M(&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ
M1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F
M:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[
M8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*
M;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I
M;F9O+3Y[8G5F?2D["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@
M;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N
M("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD
M(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R
M.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA
M;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H
M)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII
M9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA
M;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^
M("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI
M<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<
M,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@
M("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L
M("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM0
M05)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C
M=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"
M54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO
M<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B
M;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*
M<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@
M)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!
M4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L
M('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I
M('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@
M;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*
M?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@
M*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@
M*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@
M>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U
M;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@
M,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D
M,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*
M96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T
M*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T
M92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ
M1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[
M(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU
M;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR
M97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER
M92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D
M>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR87<G
M+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D<&%R(CH@
M)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ
M6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A
M<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R
M(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E96YV(#T@9&\@
M>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G3454
M02YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@
M<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*
M?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G
M+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@
M)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R
M(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@(E!+7#`P,UPP
M,#0B.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]
M($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)
M3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W
M-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=
M.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97([
M"FEF("AD969I;F5D("1D871A7W!O<RD@>PIR96%D(%]&2"P@)&QO861E<BP@
M)&1A=&%?<&]S.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R
M(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D
M97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A
M9&5R+"`D,"D["GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@
M>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D
M=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!
M4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H
M)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M
M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E
M="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*:68@*"1B=6YD;&4I
M('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`
M:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G
M<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@
M86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.
M0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*
M)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C
M=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I
M9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*
M;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE
M<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M
M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`
M:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F
M:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^
M(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO
M9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D[
M"FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]
M("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D
M969I;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT
M(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D
M+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E
M9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N
M=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT[
M"GT*96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@)&9H+"`G/#IR
M87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T[
M"B1C;VYT96YT(#T@/"1F:#X["F-L;W-E("1F:#L*4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N86UE(BD*
M:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\
M:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P
M<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&
M24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B
M)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT
M*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT
M96YT*3L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"B1Z:7`M
M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA;64@
M/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C86-H95]N86UE
M(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`]
M($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D
M;W5T.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E("1F:#L*)&-A8VAE7VYA
M;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X
M("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#
M04-(12(["B1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A
M8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP
M<FEN="@D4$%27TU!1TE#*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U
M=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*
M7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER
M92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A
M=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL
M("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E
M.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV
M93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@
M)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@
M<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!R;V=N86UE(ET["D%R
M8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!
M4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@
M/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q6UPD
M14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*:68@*&1E9FEN
M960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@
M<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2![
M"FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M
M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA
M;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO
M;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI
M"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]
M($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T
M7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M
M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M
M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N
M86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?
M;F%M92(@=&\@(B1D97-T7VYA;64B72D["B1M96UB97(M/F5X=')A8W14;T9I
M;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@
M:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A
M8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S
M86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@
M6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U
M=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA
M;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY
M("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B
M87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P
M87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I
M;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M
M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R![
M"G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT
M96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I
M<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR
M97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER
M92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP
M.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I
M<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I
M;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ
M6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER
M92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H
M0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#
M=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@
M4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP
M.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P
M='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/
M.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T
M7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%
M3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T
M=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@
M4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z
M7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H
M(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@
M)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I
M;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2![
M"B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I
M;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U
M<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-9
M4U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]
M("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E
M<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#
M3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2![
M"F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*<V5E:R`D9F@L("TQ."P@,CL*
M;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!
M0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIR96%D("1F:"P@)&)U9BP@-#$[
M"B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM
M?6-A8VAE+21B=68B.PI]"F5L<V4@>PIM>2`D9&EG97-T(#T@979A;`I["G)E
M<75I<F4@1&EG97-T.CI32$$["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W
M*#$I.PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q
M<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["B1C='@M/F%D9&9I;&4H
M)&9H*3L*8VQO<V4H)&9H*3L*)&-T>"T^:&5X9&EG97-T.PI]('Q\("1M=&EM
M93L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+21D:6=E<W0B
M.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`](#$[
M"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*?0HD14Y6
M>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@
M)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY
M("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE
M(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2![
M"FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@
M)SXZ<F%W)RP@)'1E;7!N86UE(&]R(&1I92!Q<5M#86XG="!W<FET92`B)'1E
M;7!N86UE(CH@)"%=.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@[
M"F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N
M86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE
M*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*
M:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]0
M4D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G
M;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R
M;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S
M=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D
M96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD
M97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*:68@*&]P
M96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H
M.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N
M86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@
M)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%4
M2'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@
M97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM
M?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R
M;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M
M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF
M("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?
M9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!2
M3T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]
M*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA
M;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D
M.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS
M,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@
M/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I
M9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]
M"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%
M1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)
M04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%
M0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD
M7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD
M14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X
M:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@
M/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.
M5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I
M9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU
M92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D[
M"B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!
M3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF
M("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I
M;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<[
M"G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG
M>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S
M:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C
M:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ
M9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP87(N
M<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U
M8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M93L*
M9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%
M6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@
M/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]
M?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z
M.E]?15)23U(["C$["E]?14Y$7U\*``!P97)L>'-I+F,`````````7U]%3E9?
M4$%27T-,14%.7U\@("`@("`@("`@("`@("```````1L#.P@!```@````!(?_
M_T`&``#TB?__(`$``"2*__\T`0``9(K__T@!``"TBO__;`$``,2*__^$`0``
MU(O___@!``"HC?__9`(``%2.__^,`@``>(___\`"``#8D/__``,``#23__]4
M`P``Q)/__W@#```4E/__F`,``"25___0`P``*)7__^0#``"HE___5`0``-27
M__]H!```^)?__WP$```DG?__O`0``+2=___D!```Y)W__P0%```DG___2`4`
M`+2G__^P!0``I*K__P`&```$K/__=`8``)2\__^8!@``]+S__[@&```DOO__
M\`8``-2___\D!P``5,#__U@'``!DP/__;`<``!```````````7I2``1X'@$;
M#!\`$````!@```#,B/__,``````````0````+````.B(__\\`````````"``
M``!`````%(G__T@`````00X@G02>`T*3`D[>W=,.`````!0```!D````0(G_
M_P0``````````````'````!\````.(G__P@!````00Y0G0J>"4*3")0'0I@#
MEP1#F0)$E@65!E?6U4'8UT'90][=T]0.`$$.4),(E`>5!I8%EP28`YD"G0J>
M"4_6U4'8UT'90=[=T]0.`$$.4),(E`>="IX)0I<$F`.9`D+8UT'9:````/``
M``#4B?__U`$```!!#N`!G1R>&T*7%I@51Y09DQI$U--'WMW7V`X`00[@`9,:
ME!F7%I@5G1R>&T>6%Y480IH3F10"1`K4TT'6U4':V4$+2=/4U=;9VD*4&9,:
M0I87E1A!FA.9%```)````%P!```\B___K`````!!#K`!G1:>%4.3%)0360K>
MW=/4#@!!"S````"$`0``P(O__R0!````00X@G02>`T23`F$*WMW3#@!""U8*
MWMW3#@!!"TC>W=,.```\````N`$``+",__]@`0```$(.T"!"G8H$GHD$0Y.(
M!)2'!$*5A@26A01$EX0$F(,$;PK=WM?8U=;3U`X`00L`4````/@!``#0C?__
M6`(```!!#G"=#IX-0I,,E`M#E0J6"4*7")@'2YD&F@4"0`K>W=G:U]C5UM/4
M#@!!"TB;!&,*VT$+2]M"FP1#VT*;!$/;````(````$P"``#8C___C`````!!
M#B"=!)X#0I,"E`%8WMW3U`X`'````'`"``!$D/__2`````!!#A"=`IX!2M[=
M#@`````T````D`(``'20__\(`0```$(.T$!"G8H(GHD(0I.(")2'"$.5A@B6
MA0AU"MW>U=;3U`X`00L``!````#(`@``3)'__P0`````````;````-P"```\
MD?__@`(```!"#O`A09V>!)Z=!$*9E@2:E01#DYP$E)L$0Y6:!):9!%X*W=[9
MVM76T]0.`$$+0IB7!)>8!%";E`0"0`K8UT';00M9V-=!VT&7F`28EP1!V-=#
MF)<$EY@$0IN4!````!````!,`P``3)/__R0`````````$````&`#``!DD___
M)``````````\````=`,``'23__\H!0```$$.D`&=$IX11),0E`]$E0Z6#467
M#)@+F0J:"0,@`0K>W=G:U]C5UM/4#@!!"P``)````+0#``!@F/__D`````!!
M#C"=!IX%0I,$E`-0"M[=T]0.`$$+`!P```#<`P``R)C__S``````00X0G0*>
M`4K>W0X`````0````/P#``#8F/__0`$```!!#E"="IX)0I4&E@5#EP28`T23
M")0'50K>W=?8U=;3U`X`00M-"M[=U]C5UM/4#@!!"P!D````0`0``-29__^0
M"````$(.P(,"0IVV()ZU($*;K""<JR!#E;(@EK$@29.T()2S()>P()BO($.9
MKB":K2`"G`K=WMO<V=K7V-76T]0.`$$+`LT*W=[;W-G:U]C5UM/4#@!!"P``
M`$P```"H!```_*'__^P"````00YPG0Z>#4*3#)0+0Y4*E@E"F0::!4*7")@'
M`D.;!$S;<PK>W=G:U]C5UM/4#@!!"TJ;!$S;2PJ;!$(+0IL$/````/@$``"<
MI/__8`$```!!#E"="IX)0I4&E@5#DPB4!T*7!&(*WMW7U=;3U`X`00M4"M[=
MU]76T]0.`$$+`#`````X!0``O(#__Y0"````00YPG0Z>#4*3#)0+1)4*E@F7
M"`)P"M[=U]76T]0.`$$+```@````;`4``(BE__^0$````$$.H`5&G52>4P,9
M!`K=W@X`00L<````D`4``/2U__]<`````$$.$)T"G@%5WMT.`````#0```"P
M!0``-+;__R@!````00Y`G0B>!T.3!I0%0Y4$E@-#EP*8`6D*WMW7V-76T]0.
M`$$+````,````.@%```LM___K`$```!!#D"=")X'0I,&E`5#E026`T.7`@)8
M"M[=U]76T]0.`$(+`#`````<!@``J+C__WP`````00Y`G0B>!T*3!I0%0Y4$
ME@-%EP*8`5/>W=?8U=;3U`X````0````4`8``/2X__\$`````````!````!D
M!@``\+C__PP`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````\"``````
M``"@(`````````$`````````$0,````````!`````````!P#`````````0``
M```````L`P````````$`````````-@,````````/`````````,$$````````
M#`````````#('`````````T`````````K%8````````9`````````#"K`0``
M````&P`````````(`````````!H`````````.*L!```````<``````````@`
M````````]?[_;P````"8`@````````4`````````*`X````````&````````
M`#@$````````"@````````#D!`````````L`````````&``````````5````
M`````````````````P````````!PK0$```````(`````````8``````````4
M``````````<`````````%P````````!H'`````````<`````````0!0`````
M```(`````````"@(````````"0`````````8`````````!@`````````````
M``````#[__]O``````$```@`````_O__;P````#@$P```````/___V\`````
M`P````````#P__]O``````P3````````^?__;P`````4````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````X!P```````#@'````````.`<````````X!P```````!`JP$`
M````````````````D%8`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````P4P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````05@``
M````````````````````````````````````````````````````````````
M`````````*!6````````````````````````````````````````````````
M````````````````````````8%0``````````````````$`=````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````T%(`````````````````````````
M``````````````````````````BP`0``````_____P````#(5@```````-!6
M``````````````````#85@```````.A6````````\%8```````#X5@``````
M``!7```````````````````(5P```````!!7``````````````````"(6@``
M`````$=#0SH@*$=.52D@,3`N,BXP`$=#0SH@*&-R;W-S=&]O;"U.1R`Q+C(S
M+C`N-#$X+60U.3`I(#$P+C(N,```+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N
M9VYU+F)U:6QD+6ED`"YN;W1E+D%"22UT86<`+F=N=2YH87-H`"YD>6YS>6T`
M+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN
M`"YR96QA+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M
M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA
M;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=```````````````````````
M````````````````````````````````````````````````````````````
M``````L````!`````@`````````X`@```````#@"````````&P``````````
M``````````$````````````````````3````!P````(`````````5`(`````
M``!4`@```````"0````````````````````$````````````````````)@``
M``<````"`````````'@"````````>`(````````@````````````````````
M!````````````````````#0```#V__]O`@````````"8`@```````)@"````
M````H`$````````%``````````@````````````````````^````"P````(`
M````````.`0````````X!````````/`)````````!@````,````(````````
M`!@`````````1@````,````"`````````"@.````````*`X```````#D!```
M`````````````````0```````````````````$X```#___]O`@`````````,
M$P````````P3````````U``````````%``````````(``````````@``````
M``!;````_O__;P(`````````X!,```````#@$P```````&``````````!@``
M``,````(````````````````````:@````0````"`````````$`4````````
M0!0````````H"`````````4`````````"``````````8`````````'0````$
M````0@````````!H'````````&@<````````8``````````%````%0````@`
M````````&`````````!^`````0````8`````````R!P```````#('```````
M`!@````````````````````$````````````````````>0````$````&````
M`````.`<````````X!P```````!@````````````````````$``````````0
M`````````(0````!````!@````````!`'0```````$`=````````;#D`````
M`````````````!````````````````````"*`````0````8`````````K%8`
M``````"L5@```````!0````````````````````$````````````````````
MD`````$````"`````````,!6````````P%8```````!Z/P``````````````
M````"````````````````````)@````!`````@`````````\E@```````#R6
M````````#`$```````````````````0```````````````````"F`````0``
M``(`````````2)<```````!(EP```````'@&```````````````````(````
M````````````````L`````X````#`````````#"K`0``````,*L````````(
M````````````````````"``````````(`````````+P````/`````P``````
M```XJP$``````#BK````````"`````````````````````@`````````"```
M``````#(````!@````,`````````0*L!``````!`JP```````#`"````````
M!@`````````(`````````!``````````T0````$````#`````````'"M`0``
M````<*T```````"0`@``````````````````"``````````(`````````-8`
M```!`````P``````````L`$```````"P````````@```````````````````
M``@```````````````````#<````"`````,`````````@+`!``````"`L```
M`````"@0```````````````````(````````````````````X0````$````P
M````````````````````@+`````````]`````````````````````0``````
M```!``````````$````#`````````````````````````+VP````````Z@``
=``````````````````$`````````````````````
